@@ -4,7 +4,7 @@ package Test::Class::Moose;
 
 use 5.10.0;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 use Moose 2.0000;
 use Carp;
@@ -138,11 +138,6 @@ has 'test_skip' => (
     clearer => 'test_skip_clear',
 );
 
-has '_config_p' => (
-    is  => 'ro',
-    isa => 'HashRef',
-);
-
 sub import {
     shift;
     my %args = @_;
@@ -227,7 +222,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -894,6 +889,18 @@ for you, see L<Test::Class::Moose::Role::AutoUse> in this distribution.
 
 =head1 DEPRECATIONS AND BACKWARDS INCOMPATIBILITIES
 
+=head2 Version 0.79
+
+=over 4
+
+=item *
+
+The L<Test::Class::Moose::Config> class's C<args> method is now
+deprecated. was a holdover from when Test::Class::Moose was both a parent
+class for your test classes and the test class runner.
+
+=back
+
 =head2 Version 0.77
 
 =over 4
