@@ -4,12 +4,14 @@ package Test::Class::Moose::Config;
 
 use 5.10.0;
 
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 
 use Moose;
 use Moose::Util::TypeConstraints;
 use namespace::autoclean;
 
+use Test::Class::Moose::Deprecated;
+
 subtype 'ArrayRefOfStrings', as 'Maybe[ArrayRef[Str]]';
 
 coerce 'ArrayRefOfStrings', from 'Str', via { defined($_) ? [$_] : undef };
@@ -99,6 +101,8 @@ has 'test_classes' => (
 sub args {
     my $self = shift;
 
+    Test::Class::Moose::Deprecated::deprecated();
+
     return (
         map { defined $self->$_ ? ( $_ => $self->$_ ) : () }
         map { $_->name } $self->meta->get_all_attributes
@@ -119,7 +123,7 @@ Test::Class::Moose::Config - Configuration information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.78
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -204,10 +208,9 @@ Boolean. Will run test classes in a random order.
 
 =head2 C<args>
 
- my $tests = Some::Test::Class->new($test_suite->test_configuration->args);
-
-Returns a hash of the args used to build the configuration. Used in
-testing. You probably won't need it.
+Returns a hash of the args used to build the configuration. This used to be
+used internally, but is now retained simply for backwards compatibility. You
+probably won't need it.
 
 =head1 SUPPORT
 
